package com.ruoyi.ems.service;

import java.util.List;

import com.ruoyi.ems.domain.PowerBox;

/**
 * 动力箱柜Service接口
 * 
 * @author ruoyi
 * @date 2024-08-20
 */
public interface IPowerBoxService
{
    /**
     * 查询动力箱柜
     * 
     * @param id 动力箱柜主键
     * @return 动力箱柜
     */
     PowerBox selectPowerBoxById(Long id);

    /**
     * 查询动力箱柜列表
     * 
     * @param powerBox 动力箱柜
     * @return 动力箱柜集合
     */
     List<PowerBox> selectPowerBoxList(PowerBox powerBox);

    /**
     * 新增动力箱柜
     * 
     * @param powerBox 动力箱柜
     * @return 结果
     */
     int insertPowerBox(PowerBox powerBox);

    /**
     * 修改动力箱柜
     * 
     * @param powerBox 动力箱柜
     * @return 结果
     */
     int updatePowerBox(PowerBox powerBox);

    /**
     * 批量删除动力箱柜
     * 
     * @param ids 需要删除的动力箱柜主键集合
     * @return 结果
     */
     int deletePowerBoxByIds(Long[] ids);

    /**
     * 删除动力箱柜信息
     * 
     * @param id 动力箱柜主键
     * @return 结果
     */
     int deletePowerBoxById(Long id);
}
